@@ -25,12 +25,12 @@ main(int argc, char **argv)
         for (ulong c=0; c<N; ++c)
         {
             bool q = CD_zerodiv_q(r, c);
-#ifndef TIMING
+#if !defined TIMING
             cout << (q?'1':'.');
 #endif
             ct += q;
         }
-#ifndef TIMING
+#if !defined TIMING
         cout << endl;
 #endif
     }
