@@ -17,10 +17,14 @@
 
 //% Binary numbers in a minimal-change order
 //% related so subset-lex order ("SL-Gray" order).
+//% Representation as delta-sets (binary words).
+//% Loopless generation, only O(1) data beyond the array of bits.
 //% Cf. OEIS sequence A217262.
 
+// Cf. comb/subset-sl-gray-demo.cc for representation as list of parts.
 // Cf. comb/mixedradix-sl-gray-demo.cc for the general case.
 // Cf. bits/bit-sl-gray-demo.cc for generation in a binary word.
+// Cf. comb/subset-lex-demo.cc for subset-lex order.
 
 
 //#define TIMING  // uncomment to disable printing
@@ -36,8 +40,6 @@ main(int argc, char **argv)
 #if defined TIMING
     bool bq = 0;
     NXARG(bq, "Benchmark: whether to generate in backward order");
-#else
-    cout << endl;
 #endif
 
 
@@ -47,7 +49,7 @@ main(int argc, char **argv)
     {
         cout << "forward:" << endl;
         M.first();
-    do  { ++ct; }  while ( M.next() );
+        do  { ++ct; }  while ( M.next() );
     }
     else
     {
@@ -58,6 +60,7 @@ main(int argc, char **argv)
 
 #else
 
+    cout << endl;
 //    M.last();
     do
     {
@@ -72,14 +75,10 @@ main(int argc, char **argv)
         cout << "  " << (M.dir() > 0 ? '+' : '-');
 
         // internal data (track and direction):
-        cout << "    " << M.tr_ << "  " << (M.dt_ == 1 ?  '+' : '-');
-
-//        print_bin("    ", ct, n);
-
+//        cout << "    " << M.track() << "  " << (M.track_dir() == 1 ?  '+' : '-');
 
         // Print set:
         print_deltaset_as_set("    ", M.data(), n, false );
-//        print_multi_deltaset_as_set("    ", M.data(), n, false );
 
         cout << endl;
 
@@ -102,6 +101,28 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
+Timing:GCC 12.2.0
+Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+
+time ./bin 30 0
+arg 1: 30 == n  [Number of digits]  default=6
+arg 2: 0 == bq  [Benchmark: whether to generate in backward order]  default=0
+forward:
+ ct=1073741824
+0.95user 0.00system 0:00.95elapsed 100%CPU
+ ==> 1073741824 / 0.95 == 1,130,254,551 per second
+ ==> 3.2735 cycles per update
+
+time ./bin 30 1
+arg 1: 30 == n  [Number of digits]  default=6
+arg 2: 1 == bq  [Benchmark: whether to generate in backward order]  default=0
+backward:
+ ct=1073741824
+0.79user 0.00system 0:00.79elapsed 100%CPU
+ ==> 1073741824 / 0.79 == 1,359,166,865 per second
+ ==> 2.7222 cycles per update
+
+
 Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
 
 GCC 8.3.0
@@ -112,7 +133,6 @@ forward:
 ./bin 30 0  0.85s user 0.00s system 99% cpu 0.850 total
  ==> 1073741824 / 0.85 == 1,263,225,675 per second
 
-
  time ./bin 30 1
 backward:
  ct=1073741824
