@@ -114,6 +114,15 @@ main(int argc, char **argv)
 
 
 /*
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+
+arg 1: 19 == n  [Number of paren pairs]  default=5
+ ct=1767263190
+2.16user 0.00system 0:02.16elapsed 100%CPU
+ ==> 1767263190/2.16 == 818,177,402 per second
+
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
 GCC 4.9.1:
