@@ -5,10 +5,10 @@
 #include "fxtio.h"
 #include "fxttypes.h"
 
-#include "comb/comb-print.h"
 
-
-//% Strong minimal-change order for combinations via enup (endo) steps
+//% Combinations in a strong minimal-change order (enup steps).
+//% The set (as opposed to delta set) is generated.
+//% Generation via enup/endo counting.
 
 //#define TIMING  // uncomment to disable printing
 
@@ -29,11 +29,8 @@ main(int argc, char **argv)
         ++ct;
 #if !defined TIMING
         cout << setw(4) << ct << ":";
-        const ulong *x = C.data();
-        print_set("    ", x, k);
-        print_set_as_deltaset("    ", x, k, n);
-//        print_set("    s=", C.s_, k);
-//        print_set("    a=", C.a_, k);
+        C.print_set("    ");
+        C.print_deltaset("    ");
 
 //        cout << "    ";  // composition
 //        for (ulong i=1; i<=k; ++i)  cout << " " << (x[i]-x[i-1]);
@@ -53,21 +50,22 @@ main(int argc, char **argv)
 
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
  time ./bin 32 20
 arg 1: 32 == n  [Combinations (n choose k)]  default=8
 arg 2: 20 == k  [k elements at a time]  default=3
  ct = 225792840
-./bin 32 20  5.13s user 0.02s system 99% cpu 5.161 total
- ==> 225792840/5.13 == 44,014,198 per second
+1.31user 0.00system 0:01.31elapsed 100%CPU
+==> 225792840/1.31 == 172,360,946 per second
 
  time ./bin 32 12
 arg 1: 32 == n  [Combinations (n choose k)]  default=8
 arg 2: 12 == k  [k elements at a time]  default=3
  ct = 225792840
-./bin 32 12  4.00s user 0.01s system 99% cpu 4.015 total
- ==> 225792840/4.00 == 56,448,210 per second
+1.04user 0.00system 0:01.04elapsed 100%CPU
+==> 225792840/1.04 == 217,108,500 per second
 
 */
 
