@@ -9,7 +9,10 @@
 #include "fxtio.h"
 
 
-//% Generating all compositions of n into k parts in co-lexicographic (colex) order.
+//% Generating all compositions of n into k parts
+//% in co-lexicographic (colex) order.
+
+// Cf. comb/composition-colex2-demo.cc
 
 //#define TIMING  // uncomment to disable printing
 
@@ -69,7 +72,8 @@ main(int argc, char **argv)
 
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
 ----------- next():
 
@@ -77,26 +81,26 @@ Timing:
 arg 1: 30 == n  [Compositions of n (n>=1)]  default=3
 arg 2: 10 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
 arg 3: 0 == rq  [Whether to reverse order]  default=0
-  ct=211915132
-./bin 30 10 0  1.06s user 0.00s system 99% cpu 1.061 total
- ==> 211915132/1.06 == 199,919,935 per second
+ ct=211915132
+0.35user 0.00system 0:00.35elapsed 99%CPU
+ ==> 211915132/0.35 == 605,471,805 per second
 
  time ./bin 10 30 0
 arg 1: 10 == n  [Compositions of n (n>=1)]  default=3
 arg 2: 30 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
 arg 3: 0 == rq  [Whether to reverse order]  default=0
-  ct=635745396
-./bin 10 30 0  5.70s user 0.02s system 99% cpu 5.730 total
- ==> 635745396/5.70 == 111,534,280 per second
+ ct=635745396
+1.92user 0.00system 0:01.93elapsed 99%CPU
+ ==> 635745396/1.92 == 331,117,393 per second
 
 // very sparse case:
  time ./bin 5 100
 arg 1: 5 == n  [Compositions of n (n>=1)]  default=3
 arg 2: 100 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
 arg 3: 0 == rq  [Whether to reverse order]  default=0
-  ct=91962520
-./bin 5 100  2.16s user 0.02s system 99% cpu 2.177 total
- ==> 91962520/2.16 == 42,575,240 per second
+ ct=91962520
+1.15user 0.00system 0:01.15elapsed 100%CPU
+ ==> 91962520/1.15 == 79,967,408 per second
 
 ----------- prev():
 
@@ -104,18 +108,26 @@ arg 3: 0 == rq  [Whether to reverse order]  default=0
 arg 1: 30 == n  [Compositions of n (n>=1)]  default=3
 arg 2: 10 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
 arg 3: 1 == rq  [Whether to reverse order]  default=0
-  ct=211915132
-./bin 30 10 1  1.15s user 0.00s system 99% cpu 1.160 total
- ==> 211915132/1.15 == 184,274,027 per second
+ ct=211915132
+0.40user 0.00system 0:00.40elapsed 100%CPU
+ ==> 211915132/0.40 == 529,787,830 per second
 
  time ./bin 10 30 1
 arg 1: 10 == n  [Compositions of n (n>=1)]  default=3
 arg 2: 30 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
 arg 3: 1 == rq  [Whether to reverse order]  default=0
-  ct=635745396
-./bin 10 30 1  5.97s user 0.04s system 99% cpu 6.014 total
- ==> 635745396/5.97 == 106,490,016 per second
+ ct=635745396
+1.79user 0.00system 0:01.79elapsed 100%CPU
+ ==> 635745396/1.79 == 355,165,025 per second
 
+// very sparse case:
+ time ./bin 5 100 1
+arg 1: 5 == n  [Compositions of n (n>=1)]  default=3
+arg 2: 100 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
+arg 3: 1 == rq  [Whether to reverse order]  default=0
+ ct=91962520
+1.20user 0.00system 0:01.20elapsed 100%CPU
+ ==> 91962520/1.20 == 76,635,433 per second
 */
 
 /// Emacs:
