@@ -124,8 +124,29 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing: (AMD Phenom II X4 945 3000MHz)
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
+time ./bin 30 0
+arg 1: 30 == n  [compositions of n]  default=7
+arg 2: 0 == bq  [With benchmark: whether to generate in backward order]  default=0
+forward:
+ ct=536870912
+3.19user 0.00system 0:03.19elapsed 100%CPU
+ ==> 536870912/3.19 == 168,298,091 per second
+
+
+time ./bin 30 1
+arg 1: 30 == n  [compositions of n]  default=7
+arg 2: 1 == bq  [With benchmark: whether to generate in backward order]  default=0
+backward:
+ ct=536870912
+3.01user 0.00system 0:03.01elapsed 99%CPU
+ ==> 536870912/3.01 == 178,362,429 per second
+
+
+
+Timing: (AMD Phenom II X4 945 3000MHz)
 GCC 4.9.0:
 
  time ./bin 30 0
@@ -135,7 +156,7 @@ COMPOSITION_NZ_GRAY_FIXARRAYS defined.
 forward:
  ct=536870912
 ./bin 30 0  2.97s user 0.00s system 99% cpu 2.970 total
- ==> 536870912/2.97 ==180,764,616  per second
+ ==> 536870912/2.97 == 180,764,616 per second
 
  time ./bin 30 1
 arg 1: 30 == n  [compositions of n]  default=7
