@@ -10,9 +10,9 @@
 #include "fxttypes.h"
 #include "nextarg.h"
 
-//% Compositions of n into positive parts with first part c and
+//% Compositions of n into positive parts with first part a1 and
 //%   each part <= f times its predecessor.
-//% For c=1 the same as: f-ary Huffman codes (canonical trees) with
+//% For a1=1 the same as: f-ary Huffman codes (canonical trees) with
 //%   (f-1)*n+1 terminal nodes, a[k] is the number of internal nodes of depth k.
 //% Such compositions (for f=2) are treated in
 //%   Henryk Minc: "A Problem in Partitions: Enumeration of Elements of a
@@ -31,12 +31,12 @@
 //%   arXiv:1108.5964 [math.CO], (30-August-2011).
 //%
 //% Cf. OEIS sequences:
-//% f=2:  A002572 (c=1), A002573 (c=2), A002574 (c=3),
-//%       A049284 (c=4), A049285 (c=5).
-//% c=1:  A002572 (f=2), A176485 (f=3), A176503 (f=4),
-//%       A194628 (f=5), A194629 (f=6), A194630 (f=7),
-//%       A194631 (f=8), A194632 (f=9), A194633 (f=10).
-
+//%  f=2:  A002572 (a1=1), A002573 (a1=2), A002574 (a1=3),
+//%        A049284 (a1=4), A049285 (a1=5).
+//% a1=1:  A002572 (f=2), A176485 (f=3), A176503 (f=4),
+//%        A194628 (f=5), A194629 (f=6), A194630 (f=7),
+//%        A194631 (f=8), A194632 (f=9), A194633 (f=10).
+//% f=2 and a1=1..n: A002843.
 
 
 // Cf. comb/binary-huffman-demo.cc for partitions of 1 into n powers of 1/2
@@ -48,14 +48,14 @@
 int
 main(int argc, char **argv)
 {
-    ulong n = 9;
-    NXARG(n, "compositions of n");
-    ulong c = 1;
-    NXARG(c, "first part");
+    ulong n = 8;
+    NXARG(n, "compositions of n (n >= 1)");
+    ulong a1 = 1;
+    NXARG(a1, "first part");
     ulong f = 2;
     NXARG(f, "max. ratio of consecutive parts");
 
-    composition_nz_minc P(n, c, f);
+    composition_nz_minc P(n, a1, f);
 
     ulong ct = 0;
 
@@ -76,10 +76,10 @@ main(int argc, char **argv)
 
 //        cout << "  [" << setw(2) << m << "]";
 
-        P.print_unit_partition("    ", true);
-
         P.print("  ");
+        cout << endl;
 
+        P.print_a1_sum("     ");
         cout << endl;
 
         jjassert( P.OK() );
@@ -87,7 +87,7 @@ main(int argc, char **argv)
     while ( (m=P.next()) );
 #endif  // TIMING
 
-    ct -= ( c > n );
+    ct -= ( a1 > n );
     cout << " ct=" << ct << endl;
 
     return 0;
@@ -100,7 +100,7 @@ Timing: (AMD Phenom II X4 945 3000MHz)
 
  time ./bin 38 1 2
 arg 1: 38 == n  [compositions of n]  default=9
-arg 2: 1 == c  [first part]  default=1
+arg 2: 1 == a1  [first part]  default=1
 arg 3: 2 == f  [max. ratio of consecutive parts]  default=2
  ct=1127987211
 ./bin 38 1 2  4.56s user 0.00s system 99% cpu 4.564 total
@@ -110,7 +110,7 @@ arg 3: 2 == f  [max. ratio of consecutive parts]  default=2
 // Timing with f==2 hard-coded:
  time ./bin 40 1
 arg 1: 40 == n  [compositions of n]  default=7
-arg 2: 1 == c  [first part]  default=1
+arg 2: 1 == a1  [first part]  default=1
  ct=3630948907
 ./bin 40 1  14.11s user 0.00s system 99% cpu 14.119 total
  ==> 3630948907/14.11 == 257,331,602 per second
