@@ -37,15 +37,15 @@ main(int argc, char **argv)
 
     ulong ct = 0;
 
-#ifdef TIMING
+#if defined TIMING
     bool bq = 0;
     NXARG(bq, "With benchmark: whether to generate in backward order");
-#ifdef COMPOSITION_NZ_SUBSET_LEX_FIXARRAYS
+#if defined COMPOSITION_NZ_SUBSET_LEX_FIXARRAYS
     cout << "COMPOSITION_NZ_SUBSET_LEX_FIXARRAYS defined." << endl;
 #endif
     if ( !bq )
     {
-#ifdef COMPOSITION_NZ_SUBSET_LEX_NEXT_A
+#if defined COMPOSITION_NZ_SUBSET_LEX_NEXT_A
         cout << "next() version A." << endl;
 #else
         cout << "next() version B." << endl;
@@ -56,7 +56,7 @@ main(int argc, char **argv)
     }
     else
     {
-#ifdef COMPOSITION_NZ_SUBSET_LEX_PREV_A
+#if defined COMPOSITION_NZ_SUBSET_LEX_PREV_A
         cout << "prev() version A." << endl;
 #else
         cout << "prev() version B." << endl;
