@@ -21,6 +21,7 @@
 //%   vol.140, no.6, pp.1550-1562, (June-2010).
 //% Cf. OEIS sequence A219282.
 
+// Cf. comb/composition-nz-subdiagonal-demo.cc
 // Cf. comb/partition-strongly-decr-desc-demo.cc for strongly decreasing partitions
 // Cf. comb/partition-nonsquashing-desc-demo.cc for non-squashing partitions
 
@@ -72,7 +73,7 @@ main(int argc, char **argv)
 
         jjassert( P.OK() );
     }
-    while ( (m=P.next()) );
+    while ( 0 != (m=P.next()) );
 #endif  // TIMING
 
     cout << " ct=" << ct << endl;
@@ -83,6 +84,25 @@ main(int argc, char **argv)
 
 
 /*
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+
+time ./bin 90
+arg 1: 90 == n  [superdiagonal compositions of n]  default=13
+arg 2: 0 == aa  [Whether to render as ASCII art]  default=0
+ ct=2291164450
+5.63user 0.00system 0:05.63elapsed 100%CPU
+ ==> 2291164450/5.63 == 406,956,385 per second
+
+// with code for easy case:
+time ./bin 90
+arg 1: 90 == n  [superdiagonal compositions of n]  default=13
+arg 2: 0 == aa  [Whether to render as ASCII art]  default=0
+ ct=2291164450
+4.75user 0.00system 0:04.76elapsed 99%CPU
+ ==> 2291164450/4.75 == 482,350,410 per second
+
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
  time ./bin 90
