@@ -489,7 +489,22 @@ bool cond_leq_23(const ulong *a, ulong k)
 
 bool cond_test(const ulong *a, ulong k)  // last arg = 99
 {
+    // for rising factorial basis:
+    if ( k >= 1 )
+    {
+        const ulong d0 = a[k], d1 = a[k-1];
+        if ( d1 > d0 )  // fall
+        {
+            return ( d1 - d0 <= 1 ); // A264868  // without else
+        }
+        else
+        {
+            return ( d0 - d1 <= 1 );  // A005773
+        }
+    }
+    return true;
 
+#if 0
     // A333647 (one leading 1 less, we are looking at internal levels)
     if ( k == 0 )
     {
@@ -518,6 +533,7 @@ bool cond_test(const ulong *a, ulong k)  // last arg = 99
     }
 
     return true;
+#endif
 #if 0
     // A328357 with rfact:  (only for n >= 2)
     // implicit 0==a[-1] <= a[0]
@@ -646,7 +662,7 @@ main(int argc, char **argv)
 #if !defined TIMING
         cout << " " << setw(4) << ct << ":";
         M.print("  ", true );
-        cout << "  " << M.pos();
+//        cout << "  " << M.pos();
         cout << endl;
 #endif
 
@@ -673,7 +689,7 @@ arg 3: 4 == c  [Condition function: ... ]
 
 */
 
-// % echo $(for n in $(seq 0 11); do ./bin $n 1 150 | grep ct= | sed 's/ ct=//;s/$/, /;' ; done)
+//  echo $(for n in $(seq 0 11); do ./bin $n 1 99 | grep ct= | sed 's/ ct=//;s/$/, /;' ; done)
 
 
 /// Emacs:
