@@ -1,8 +1,9 @@
 
-#include "comb/mset-perm-lex.h"
 #include "comb/mset-kperm-lex.h"
+// demo-include "comb/mset-perm-lex.h"
 
-//#include "comb/comb-print.h"
+#include "comb/fact2perm.h"
+#include "comb/comb-print.h"
 
 #include "fxttypes.h"
 #include "fxtio.h"
@@ -28,7 +29,8 @@ main(int argc, char **argv)
     cout << "args: multiplicities of elements" << endl;
     if ( argc<=2 )
     {
-        ulong t[]={3, 2, 1, 0};  // proper multisets  ct=30
+        ulong t[]={2, 2, 2, 0};  // proper multisets  ct=54
+//        ulong t[]={3, 2, 1, 0};  // proper multisets  ct=30
 //        ulong t[]={1, 1, 1, 1, 0};  // permutations  ct = 24
 //        ulong t[]={6, 2, 0};  // combinations  ct=28
         k=0;  while ( t[k] )  { ++k; }
@@ -66,6 +68,7 @@ main(int argc, char **argv)
 
 #else  // TIMING
 
+//    ulong F[n];
     const bool dfz = true;  // whether to print dots for zeros
     ulong j = plen;
     do
@@ -75,6 +78,9 @@ main(int argc, char **argv)
         P.print("  ", dfz);
         P.print_suffix("  ", dfz);
         cout << setw(4) << j;
+//        perm2ffact( P.data(), n, F);
+//        print_vec( "    ", F, n-1, true );
+
         cout << endl;
     }
     while ( n != (j=P.next()) );
@@ -92,26 +98,38 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing: (Intel Xeon CPU E3-1275 V2 @ 3.50GHz)
-
-GCC 6.3.0
-
-
- time  ./bin 12 1 1 1 1 1 1 1 1 1 1 1 1  ## all permutations of 12
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+time  ./bin 12 1 1 1 1 1 1 1 1 1 1 1 1  ## all permutations of 12
 arg 1: 12 == plen  [length of prefix]  default=4
 args: multiplicities of elements
 multiplicities: ( 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 )  k=12  n=12
  ct=479001600
-./bin 12 1 1 1 1 1 1 1 1 1 1 1 1  2.18s user 0.00s system 99% cpu 2.186 total
- ==> 479001600 / 2.18 == 219,725,504 per second
+1.75user 0.00system 0:01.75elapsed 100%CPU
+ ==> 479001600 / 1.75  == 273,715,200 per second
 
  time  ./bin 10 1 1 1 1 1 1 1 1 1 1 1 1  ## 10-prefixes of permutations of 12
-arg 1: 10 == plen  [length of prefix]  default=4
-args: multiplicities of elements
+ args: multiplicities of elements
 multiplicities: ( 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 )  k=12  n=12
  ct=239500800
-./bin 10 1 1 1 1 1 1 1 1 1 1 1 1  1.26s user 0.00s system 99% cpu 1.263 total
- ==> 239500800 / 1.26 == 190,080,000 per second
+1.22user 0.00system 0:01.22elapsed 100%CPU
+ ==> 239500800 / 1.22  == 196,312,131 per second
+
+time ./bin 7 2 2 2 2 2 2 2 2 2 2 2 2 2  ## 7-prefixes of permutations of [2^13]
+arg 1: 7 == plen  [length of prefix]  default=4
+args: multiplicities of elements
+multiplicities: ( 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2 )  k=13  n=26
+ ct=52612560
+1.61user 0.00system 0:01.61elapsed 100%CPU
+ ==> 52612560 / 1.61 == 32,678,608 per second
+
+time ./bin 8 3 3 3 3 3 3 3 3 3 3 3  ## 8-prefixes of permutations of [3^11]
+arg 1: 8 == plen  [length of prefix]  default=4
+args: multiplicities of elements
+multiplicities: ( 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3 )  k=11  n=33
+ ct=206015040
+8.16user 0.00system 0:08.16elapsed 100%CPU
+ ==> 206015040 / 8.16 == 25,246,941 per second
 
 */
 
