@@ -102,7 +102,6 @@ main(int argc, char **argv)
 //        cout << setw(4) << T.height();
 
 //        T.print_branching_numbers("    ");
-
 //        T.print_paren_word("    ", "()");
 //        T.print_paren_word("    ", "1.");
 
@@ -133,6 +132,18 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
+
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+
+time ./bin 19
+arg 1: 19 == n  [Number of non-root nodes]  default=5
+arg 2: 0 == aa  [Whether to render trees as ASCII art]  default=0
+ ct=1767263190
+2.31user 0.00system 0:02.31elapsed 100%CPU
+ ==> 1767263190/2.31 == 765,049,000 per second
+
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
 GCC 4.9.0:
