@@ -25,7 +25,7 @@ main(int argc, char **argv)
 
     perm_derange P(n);
 
-#ifdef TIMING
+#if defined TIMING
 
     while ( P.next() )  {;}
 
