@@ -72,6 +72,16 @@ main(int argc, char **argv)
 /*
 Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
 
+GCC 12.2.0
+
+time ./bin 13
+PERM_LEX_FIXARRAYS is defined.
+PERM_LEX_OPT is defined.
+ct=6227020800
+./bin 13 7.39s user 0.00s system 99% cpu 7.39s total
+ ==> 6227020800/7.39 == 842.627983 [M per second];  1/rate == 4.39 [cycles]
+
+
 GCC 10.2.1
 
  time ./bin 13
