@@ -13,28 +13,20 @@
 
 //% Single track ordering for permutations, swaps in prefix, CAT algorithm.
 
+// Cf. seq/A368948-demo.cc
+
 //#define TIMING  // uncomment to disable printing
 
 
-//#define SHOW_FACT  // uncomment to show factorial representations
-#if defined SHOW_FACT
-#include "comb/fact2perm.h"
-#endif
-
-
 int
 main(int argc, char **argv)
 {
     ulong n = 4;
     NXARG(n, "Number of elements to permute");
 
-    bool iq = true;
-    NXARG(iq, "Whether first permutation is the identical permutation");
-
     perm_st_pref P(n);
     P.first();
 
-
     ulong ct = 0;
 
 #if defined TIMING
@@ -44,44 +36,24 @@ main(int argc, char **argv)
 #else  // TIMING
 
     const bool dfz= true;  // whether to print dots for zeros
-
-#if defined SHOW_FACT
-    ulong *rfc = new ulong[n];  // rising factorial
-    const ulong *x = P.data();
-    const ulong *xi = P.invdata();
-#endif
-
-    if ( iq )  P.first_id();
-    else       P.first();
-
     do
     {
         cout << setw(4) << ct << ":";
         P.print("    ", dfz);
-
         P.print_inv("    ", dfz);
-
-#if defined SHOW_FACT
-//        perm2ffact(x, n, rfc);
-//        print_mixedradix("    ", rfc, n-1, dfz);
-        perm2rfact(x, n, rfc);
-        print_mixedradix("    ", rfc, n-1, dfz);
-        perm2rfact(xi, n, rfc);
-        print_mixedradix("    ", rfc, n-1, dfz);
-#else
-        print_mixedradix("    ", P.d_, n-1, dfz);
-#endif
+        print_mixedradix("    ", P.M, n-(n!=0), dfz);
 
         if ( ct != 0 )
         {
             // print swaps:
-            // (positions in inverse permutation, or elements in permutation)
+            // (elements in permutation, or positions in inverse permutation)
             ulong j = 0;
-            while ( P.d_[j] == 0 )  { ++j; }
+            while ( P.M[j] == 0 )  { ++j; }
             cout << "    " << j << ": ";
             for (ulong e1=j&1, e2=e1+1;  e1<=j;  e1+=2, e2+=2)
             {
-                cout << "(" << e1 << "," << e2 << ") ";
+                cout << "(" << e1 << "," << e2 << ")";
+                if ( e1 < j )  cout << " ";
             }
         }
 
@@ -90,11 +62,6 @@ main(int argc, char **argv)
     }
     while ( P.next() );
 
-#if defined SHOW_FACT
-    delete [] rfc;
-#endif
-
-
 #endif  // TIMING
 
     cout << " ct=" << ct << endl;
@@ -103,11 +70,24 @@ main(int argc, char **argv)
 }
 // -------------------------
 
+/*
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+
+time  ./bin 12
+arg 1: 12 == n  [Number of elements to permute]  default=4
+arg 2: 1 == iq  [Whether first permutation is the identical permutation]  default=1
+ ct=479001600
+1.16user 0.00system 0:01.16elapsed 100%CPU
+ ==> 12!/1.16 == 412,932,413 per second
+
+*/
+
 /*
 Timing: (AMD Phenom II X4 945 3000MHz)
 
 // using for-loop; in next():
-% time  ./bin 12
+time  ./bin 12
 arg 1: 12 == n  [Number of elements to permute]  default=4
 arg 2: 1 == iq  [Whether first permutation is the identical permutation]  default=1
  ct=479001600
@@ -115,7 +95,7 @@ arg 2: 1 == iq  [Whether first permutation is the identical permutation]  defaul
  ==> 12!/2.36 == 202,966,779 per second
 
 // using do ... while in next():
-% time  ./bin 12
+time  ./bin 12
 arg 1: 12 == n  [Number of elements to permute]  default=4
 arg 2: 1 == iq  [Whether first permutation is the identical permutation]  default=1
  ct=479001600
@@ -124,16 +104,6 @@ arg 2: 1 == iq  [Whether first permutation is the identical permutation]  defaul
 
 */
 
-/*
-Sequence(s):  (not in OEIS)  A000000
-
-% echo $(./bin 5 | cut -b 12 | sed 's/\./0/g;') | sed 's/ /,/g;'
-0,1,2,2,1,0,1,0,0,1,2,2,3,3,3,3,3,3,2,2,1,0,0,1,2,2,1,0,0,1,0,1,2,2,1,0,...
-
-% echo $(./bin 5 | cut -b 12 | sed 's/\./0/g;') | sed 's/ /,/g;' | tr '0123456' '1234567'
-1,2,3,3,2,1,2,1,1,2,3,3,4,4,4,4,4,4,3,3,2,1,1,2,3,3,2,1,1,2,1,2,3,3,2,1,...
-
-*/
 
 
 /// Emacs:
