@@ -29,7 +29,7 @@ main(int argc, char **argv)
     do
     {
         ++ct;
-#ifndef TIMING
+#if !defined TIMING
         cout << setw(4) << ct << ":";
         R.print("    ", true);
         cout << endl;
