@@ -25,7 +25,7 @@ int
 main(int argc, char **argv)
 {
     ulong n = 5;
-#ifdef SETPART_RGS_SUBSET_LEX_SC
+#if defined SETPART_RGS_SUBSET_LEX_SC
     NXARG(n, "Length of RGS");
 #else
     NXARG(n, "Length of RGS (n>=2)");
@@ -38,8 +38,8 @@ main(int argc, char **argv)
     if ( bw )  P.last();
 
     ulong ct = 0;
-#ifdef TIMING
-#ifdef SETPART_RGS_SUBSET_LEX_SC
+#if defined TIMING
+#if defined SETPART_RGS_SUBSET_LEX_SC
     cout << "SETPART_RGS_SUBSET_LEX_SC is defined" << endl;
 #endif
     if ( bw )
