@@ -61,7 +61,7 @@ main(int argc, char **argv)
     ulong * st = new ulong[n+1];  // stats
     for (ulong k=0; k<n+1; ++k)  st[k] = 0;
 
-#ifndef TIMING
+#if !defined TIMING
     const ulong *x = T.data();
 #endif
 
@@ -461,7 +461,7 @@ main(int argc, char **argv)
         st[ s ] += 1;
 
 
-#ifndef TIMING
+#if !defined TIMING
         cout << setw(4) << ct << ":";
 
         // print RGS:
