@@ -53,7 +53,7 @@ main(int argc, char **argv)
     ulong ct = 0;
 
 
-#ifdef TIMING
+#if defined TIMING
 
     Y.first();
     do  { ++ct; }  while ( Y.next() );
