@@ -8,7 +8,7 @@
 #include "aux0/swap.h"
 #include "fxttypes.h"
 
-#include "perm/permq.h"  // is_cyclic(), ...
+#include "perm/permq.h"  // perm_is_cyclic(), ...
 #include "jjassert.h"
 
 #include "nextarg.h"  // NXARG()
@@ -20,7 +20,7 @@
 #if defined TIMING
 void visit(const ulong *f, ulong n, ulong)
 {
-    jjassert( is_cyclic(f, n) );
+    jjassert( perm_is_cyclic(f, n) );
 }
 #else  // TIMING
 void visit(const ulong *f, ulong n, ulong ct)
@@ -32,10 +32,10 @@ void visit(const ulong *f, ulong n, ulong ct)
     cout << "    ";
     print_cycle(f, 0);
 
-//    if ( is_connected(f, n) )  cout << "  Ind";  // always true
-//    if ( is_updown_permutation(f, n) )  cout << "  UpD";
-//    if ( is_derangement(f, n) )  cout << "  Der";  // always true
-//    if ( is_cyclic(f, n) )  cout << "  Cyc";
+//    if ( perm_is_connected(f, n) )  cout << "  Ind";  // always true
+//    if ( perm_is_updown_permutation(f, n) )  cout << "  UpD";
+//    if ( perm_is_derangement(f, n) )  cout << "  Der";  // always true
+//    if ( perm_is_cyclic(f, n) )  cout << "  Cyc";
     cout << endl;
 }
 // -------------------------
