@@ -1,6 +1,6 @@
 
 #include "comb/perm-lex.h"  // with factorial numbers
-#include "perm/permq.h"  // major_index()
+#include "perm/permq.h"  // perm_major_index()
 
 #include "comb/comb-print.h"
 
@@ -29,7 +29,7 @@ main(int argc, char **argv)
     do
     {
         const ulong ni = P.num_inversions();
-        const ulong mi = major_index(P.x_, n);
+        const ulong mi = perm_major_index(P.x_, n);
         if ( ni != mi )  continue;
 
         ++ct;
