@@ -12,7 +12,7 @@ export MAKEFLAGS='';
 
 if test -z ${JUST_BITS}; then
     make 1test  TESTSRC=test/test-include-all.cc  || exit 1
-    make 1test  TESTSRC=test/test-transpose.cc  || exit 1
+#    make 1test  TESTSRC=test/test-transpose.cc  || exit 1
     make 1test  TESTSRC=test/test-fact.cc  || exit 1
     make 1test  TESTSRC=test/test-permute.cc  || exit 1
     make 1test  TESTSRC=test/test-fht.cc  || exit 1
