@@ -25,28 +25,28 @@ class catalan_rgs
 //  1, 1, 2, 5, 14, 42, 132, 429, 1430, 4862, 16796, ...
 // Sequence A239903 gives the RGS.
 {
-public:
+private:
 #if !defined CATALAN_RGS_FIXARRAYS
-    ulong *a_;  // digits of the RGS: a_[k] <= a[k-1] + 1
+    ulong *A;  // digits of the RGS: a[k] <= a[k-1] + 1
 #else
-    ulong a_[64];
+    ulong A[64];
 #endif
-    ulong n_;   // Number of digits (paren pairs)
+    ulong n;   // Number of digits (paren pairs)
 
-    char *str_;  // paren string
+    char *S;  // paren string
 
     catalan_rgs(const catalan_rgs&) = delete;
     catalan_rgs & operator = (const catalan_rgs&) = delete;
 
 public:
-    explicit catalan_rgs(ulong n)
+    explicit catalan_rgs(ulong tn)
     {
-        n_ = n;
+        n = tn;
 #if !defined CATALAN_RGS_FIXARRAYS
-        a_ = new ulong[n_ + 1];
+        A = new ulong[n + 1];
 #endif
-        str_ = new char[2*n_+1];
-        str_[2*n_] = 0;
+        S = new char[2*n+1];
+        S[2*n] = 0;
 
         first();
     }
@@ -54,30 +54,30 @@ public:
     ~catalan_rgs()
     {
 #if !defined CATALAN_RGS_FIXARRAYS
-        delete [] a_;
+        delete [] A;
 #endif
-        delete [] str_;
+        delete [] S;
     }
 
-    const ulong *data()  const  { return a_ + 1; }
-    ulong size()  const  { return n_ + 1; }
+    const ulong *data()  const  { return A + 1; }
+    ulong size()  const  { return n + 1; }
 
     void first()
-    { for (ulong k=0; k<size(); ++k)  a_[k] = 0; }
+    { for (ulong k=0; k<size(); ++k)  A[k] = 0; }
 
 
     ulong next()
     // Return position of leftmost change, zero with last.
     {
-        ulong j = n_;
+        ulong j = n;
         while ( j > 1 )
         {
-            if ( a_[j] <= a_[j-1] )
+            if ( A[j] <= A[j-1] )
             {
-                ++a_[j];
+                ++A[j];
                 return j - 1;
             }
-            a_[j] = 0;
+            A[j] = 0;
             --j;
         }
 
@@ -87,25 +87,25 @@ public:
 
     const char* bit_string()
     {
-        for (ulong k=0; k<2*n_; ++k)  str_[k] = '.';
+        for (ulong k=0; k<2*n; ++k)  S[k] = '.';
         const ulong *a = data();
-        for (ulong k=0, j=0;  k<n_;  ++k, j+=2)  str_[ j - a[k] ] = '1';
-        return str_;
+        for (ulong k=0, j=0;  k<n;  ++k, j+=2)  S[ j - a[k] ] = '1';
+        return S;
     }
 
     const char* paren_string()
     {
-        for (ulong k=0; k<2*n_; ++k)  str_[k] = ')';
+        for (ulong k=0; k<2*n; ++k)  S[k] = ')';
         const ulong *a = data();
-        for (ulong k=0, j=0;  k<n_;  ++k, j+=2)  str_[ j - a[k] ] = '(';
-        return str_;
+        for (ulong k=0, j=0;  k<n;  ++k, j+=2)  S[ j - a[k] ] = '(';
+        return S;
     }
 
     void print(const char *bla, bool dfz=true)  const
-    { print_vec(bla, data(), n_, dfz); }
+    { print_vec(bla, data(), n, dfz); }
 
     bool OK()  const
-    { return is_catalan_rgs(data(), n_); }
+    { return is_catalan_rgs(data(), n); }
 };
 // -------------------------
 
