@@ -44,7 +44,8 @@ void
 swt_normalize(double *f, ulong n)
 // Normalization for the square wave transform.
 {
-    constexpr double s2 = sqrt(0.5);
+//    constexpr double s2 = sqrt(0.5);
+    constexpr double s2 = 0.70710678118654752440084436210484903928;
     if ( n <= 2 )
     {
         if ( n == 2 )
